package com.example.nto.config;

import com.amazonaws.SdkClientException;
import com.amazonaws.auth.AWSStaticCredentialsProvider;
import com.amazonaws.auth.BasicAWSCredentials;
import com.amazonaws.services.s3.AmazonS3;
import com.amazonaws.services.s3.AmazonS3ClientBuilder;
import lombok.Getter;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;

@Slf4j
@Getter
@Configuration
public class ObjectStorageConfig {
    @Value("${yandex.cloud.region}")
    private String region;
    @Value("${yandex.cloud.s3_endpoint}")
    private String s3Endpoint;

    @Value("${yandex.cloud.bucket}")
    private String bucketName;
    @Value("${yandex.cloud.key_id}")
    private String accessKeyId;
    @Value("${yandex.cloud.secret_key}")
    private String secretAccessKey;


    public AmazonS3 createAmazonS3() {
        // Создание клиента AmazonS3 с подключением к Object Storage
        try {
            return AmazonS3ClientBuilder.standard()
                    .withEndpointConfiguration(new com.amazonaws.client.builder.AwsClientBuilder.EndpointConfiguration(s3Endpoint, region))
                    .withCredentials(new AWSStaticCredentialsProvider(new BasicAWSCredentials(accessKeyId, secretAccessKey)))
                    .build();
        } catch (SdkClientException e) {
            log.error("Ошибка при создании клиента для хранения объектов с помощью AWS SDK. Причина: {}", e.getMessage());
            throw new SdkClientException(e.getMessage());
        }
    }
}
